Learn R Programming

ggrecipes (version 0.1.0)

ggrecipes-package: ggrecipes: Recipes for Data Visualization

Description

logo

A collection of custom ggplot2-based visualizations for data exploration and analysis. Each function handles data preprocessing and returns a ggplot2 object that can be further customized using standard ggplot2 syntax.

Arguments

Author

Maintainer: Ignophi Hu ignophi.hu@pm.me (ORCID) [copyright holder]

See Also